@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v2.4.3");
+use version; our $VERSION = version->declare("v2.4.4");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -52,7 +52,7 @@ As stated above, Minilla is opinionated. Minilla has a bold assumption and conve
 
 =item Your module has a Changes file
 
-=item Your module requires at least perl 5.8.1
+=item Your module requires at least perl 5.6.
 
 =back
 
@@ -406,6 +406,12 @@ You need to rewrite minil.toml file and add the following line:
 I don't suggest to use this module... But you can use this option for maintaining
 primitive modules like Test::TCP.
 
+=item Ho do I support Perl 5.6?
+
+EUMM can run on Perl 5.6. Write following statement in your minil.toml file.
+
+    module_maker="ExtUtilsMakeMaker"
+
 =back
 
 =head1 AUTHORS
